/*
 * playlist.h
 *
 *  Created on: 18.11.2009
 *      Author: darkstar
 */

#ifndef PLAYLIST_H_
#define PLAYLIST_H_

#include <qobject.h>

#include "mediadatabase.h"

class PlayList : public QObject
{
	Q_OBJECT
public:
	PlayList(MediaDatabase *mediaDatabase, const QString dbTable);
	virtual ~PlayList();

	const QString sourceTable() const { return dbTable_; }

	void clear();

	void addFile(const QString &fileName);
	void addURL(const QString &url);
	void addDir(const QString &directory);

	void appendMediaIDs(const QValueList<unsigned long> &mediaIDs);
	int getNextIndex() const;

	bool isDynamicPlayList() { return isDynamicPlayList_; }
	void setDynamicPlayList(bool value);
	void repopulate();

	bool loadFromFile(const QString &filename);
	const QString saveToFile(const QString &filename);

signals:
	void playListChanged();

private slots:
	void mediaDatabasePreparingStatements(sqlite3 *db);
	void mediaDatabaseFinalizingStatements(sqlite3 *db);

private:
	MediaDatabase *mediaDatabase_;
	QString dbTable_;

	sqlite3_stmt *stmtSelectTotalFileSizeAndCountForMediaLocation;
	sqlite3_stmt *stmtSelectAllMediaIDsForMediaLocation;
	sqlite3_stmt *stmtInsertMediaIDIntoPlaylist;

	bool isDynamicPlayList_;
	QExtStringList dynPlayList_;

	int updateCount_;

	void beginUpdate();
	void endUpdate();
	void propagateChanges();

	void fillFileList(QExtStringList &filelist, const QString &path, const bool subdir);
	void addFromPlayList(const QExtStringList &filelist, bool interpretPlayList, const QString &playlistDirectory);
};

#endif /* PLAYLIST_H_ */
